<?php

namespace Modules\OpcData\Http\Controllers\Api\zaoquan;

use App\Http\Controllers\Api\BaseController;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Modules\OpcData\Services\zaoquan\ZQDcsApiService;

/**
 * 枣泉自动化——东井通风
 */
class ZQDcsFanController  extends BaseController
{

    private $db_name='etl_zaoquan';

    protected $apiService;
    protected $apiUrl = 'http://zdh.zaoquan.nxjiewei.com:8011/v1/common/GetPointRealDataByPageV3';

    public function __construct(ZQDcsApiService $apiService)
    {
        parent::__construct();
        $this->apiService = $apiService;
    }

    public function getList(Request $request) {
        $sysCode = isset($request->sys_code) ? $request->sys_code : null;     // 矿分类
        if ($sysCode == null) {
            $msg="参数为空";
            $code=-1;
            return $this->error($code, $msg);
        } else {
            switch ($sysCode) {
                case 'east': // 东井
                    return $this->getEastList();
                case 'west': // 西井
                    return $this->getWestList();
                case '1314': // 1314立井
                    return $this->get1314List();
                case '5fq': // 五分区
                    return $this->get5fqList();
                case '1200car': // 1200车场 * 150201机巷通风机
                    return $this->get1200CarFanList();
                case '1200sm': // 1200石门 * 150201回风巷通风机
                    return $this->get1200smList();
                case '220708fzx': // 220708辅助巷
                    return $this->get220708fzxList();
                case '220708jdx': // 220708胶带巷
                    return $this->get220708jdxList();
                case '220708hfx': // 220708回风巷
                    return $this->get220708hfxList();
                case '110207hfx': // 110207回风巷
                    return $this->get110207hfxList();
                case '110207jx': // 110207机巷
                    return $this->get110207jxList();
                case '250602hfx': // 250602回风巷
                    return $this->get250602hfxList();
                case '13207jx': // 13207机巷
                    return $this->get13207jxList();
                case 'index': // 13207机巷
                    return $this->getInfoList();
                default:
                    $msg="未知数据";
                    $code=-2;
                    return $this->error($code, $msg);
            }
        }
    }

    /*
     * 通风入口接口
     * */
    public function getInfoList() {

        $keys=[
            "2008319841133569_2", "2008319841389569_2" // 东井
            ,"2009735056108545_2", "2009735056749569_2" // 西井
            ,"2009721035631617_2", "2009721047067649_2" // 1314立井
            ,"2074993339513857_2", "2074993343917057_2" // 13207机巷
            ,"2063316486075393_2", "2063316488862721_2" // 250602回风巷
            ,"2059629794612225_2", "2059629795228673_2" // 110207机巷 -
//            ,"2059629794612225_2", "2059629795228673_2" // 110207回风巷 -
            ,"2074999786576897_2", "2074999790310401_2" // 五六分区220708回风巷
            ,"2046522721719297_2", "2046522723800065_2" // 五六分区220708胶带巷
            ,"2046535459097601_2", "2046535461340161_2" // 五六分区220708辅助巷
            ,"2046522721719297_2", "2046522723800065_2" // 五六分区1200石门 150201回风巷通风机
            ,"2049479008105473_2", "2049479008132097_2" // 五六分区1200车场 150201机巷通风机
            ,"2008681964219393_2", "2008682656793601_2" // 五分区通风系统
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys);

        // 获取风门数据
        // 自动风门 http://7.250.4.5:1434/zqk/api/AutomaticAirDoors/AutomaticAirDoor
        // 自动风窗 http://7.250.4.5:1434/zqk/api/AutomaticWindDevices/AutomaticWindDevice
        // 变频局扇 http://7.250.4.5:1434/zqk/api/LocalFans/LocalFan

        $autoAirDoorsUrl = 'http://7.250.4.5:1434/zqk/api/AutomaticAirDoors/AutomaticAirDoor';
        $autoWindDevicesUrl = 'http://7.250.4.5:1434/zqk/api/AutomaticWindDevices/AutomaticWindDevice';
        $LocalFansUrl = 'http://7.250.4.5:1434/zqk/api/LocalFans/LocalFan';


        $autoAirDoorsData = $this->apiService->getApiData($autoAirDoorsUrl);
        $autoWindDevicesData = $this->apiService->getApiData($autoWindDevicesUrl);
        $LocalFansData = $this->apiService->getApiData($LocalFansUrl);

        // 获取饼图数据（数据库）
        // cq.wind.online_chart
        $data = $this->getDBDataFrom('data_websocket', "sys_type='cq.wind.online_chart'");
        $dataStr = $data[0]->data;
        $data = str_replace("'", '"', $dataStr);
        $windData = json_decode($data, true);

        $info = [
            "charData_1"=>[
                "series"=>[
                    "data"=>[
                        [
                            "name"=>"有效风",
                            "value"=>round($windData['vaildWindRate'], 1)
                        ],
                        [
                            "name"=>"无效风",
                            "value"=>round(1-$windData['vaildWindRate'], 1)
                        ]
                    ]
                ]
            ],
            "charData_2"=>[
                "series"=>[
                    "data"=>[
                        [
                            "name"=>"供风量",
                            "value"=>$windData['needTotalQuantity']
                        ],
                        [
                            "name"=>"需风量",
                            "value"=>$windData['needQuantity']
                        ]
                    ]
                ]
            ],
            "info"=>[
                [
                    "label"=>"自动风门",
                    "value"=>count($autoAirDoorsData['data'])."扇"
                ],
                [
                    "label"=>"自动风窗",
                    "value"=>count($autoWindDevicesData['data'])."扇"
                ],
                [
                    "label"=>"变频风扇",
                    "value"=>count($LocalFansData['data'])."扇"
                ]
            ],
            "list"=>[
                [
                    "title"=>"东井通风机",
                    "sys_code"=>"east",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2008319841133569_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2008319841389569_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"西井通风机",
                    "sys_code"=>"west",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2009735056108545_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2009735056749569_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"1314立井通风机",
                    "sys_code"=>"1314",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2009721035631617_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2009721047067649_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"五分区通风机",
                    "sys_code"=>"5fq",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2008681964219393_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2008682656793601_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],

                [
                    "title"=>"150201回风巷通风机",
                    "sys_code"=>"1200sm",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2046522721719297_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2046522723800065_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"150201机巷通风机",
                    "sys_code"=>"1200car",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2049479008105473_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2049479008132097_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"220708辅助巷",
                    "sys_code"=>"220708fzx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2046535459097601_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2046535461340161_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"220708回风巷",
                    "sys_code"=>"220708hfx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2074999786576897_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2074999790310401_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"220708胶带巷",
                    "sys_code"=>"220708jdx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2046522721719297_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2046522723800065_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"110207回风巷",
                    "sys_code"=>"110207hfx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2059629794612225_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2059629795228673_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"110207机巷通风机",
                    "sys_code"=>"110207jx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2059629794612225_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2059629795228673_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"250602回风巷通风机",
                    "sys_code"=>"250602hfx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2063316486075393_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2063316488862721_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"13207机巷通风机",
                    "sys_code"=>"13207jx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData['2074993339513857_2'] ?? 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData['2074993343917057_2'] ?? 0,
                            "text"=>"运行"
                        ]
                    ]
                ]
            ]
        ];

        return json_encode($info);
    }
    /*
     * 13207机巷
     */
    public function get13207jxList() {

        $keys=[
            "2074993339513857_2","2074993340347393_2","2074993343917057_2","2074993344812033_2",
            "2074993350050817_1","2074993350003713_1","2074993349954561_1","2074993348475905_1",
            "2074993349905409_1","2074993348156417_1","2074993348262913_1","2074993348373505_1",
            "2074993349594113_1","2074993349702657_1","2074993349803009_1","2074993348207617_1",
            "2074993348316161_1","2074993348426753_1","2074993349647361_1","2074993349753857_1",
            "2074993349852161_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>  $baseData['2074993339513857_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2074993350050817_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电压',
                        "unit"=>"V",
                        "num"=> $baseData['2074993350003713_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=> $baseData['2074993339513857_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=> $baseData['2074993340347393_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2074993343917057_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2074993350050817_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电量',
                        "unit"=>"%",
                        "num"=> $baseData['2074993349954561_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2074993343917057_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2074993344812033_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    'label'=>'电压（V）',
                    'value_1'=>$baseData['2074993348475905_1'] ?? 0,
                    'value_2'=>$baseData['2074993349905409_1'] ?? 0,
                ],
                [
                    "label"=>"Ia1电流（A）",
                    'value_1'=>$baseData['2074993348156417_1'] ?? 0,
                    'value_2'=>$baseData['2074993349594113_1'] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    'value_1'=>$baseData['2074993348262913_1'] ?? 0,
                    'value_2'=>$baseData['2074993349702657_1'] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    'value_1'=>$baseData['2074993348373505_1'] ?? 0,
                    'value_2'=>$baseData['2074993349803009_1'] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    'value_1'=>$baseData['2074993348207617_1'] ?? 0,
                    'value_2'=>$baseData['2074993349647361_1'] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    'value_1'=>$baseData['2074993348316161_1'] ?? 0,
                    'value_2'=>$baseData['2074993349753857_1'] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    'value_1'=>$baseData['2074993348426753_1'] ?? 0,
                    'value_2'=>$baseData['2074993349852161_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 250602回风巷
     */
    public function get250602hfxList() {

        $keys=[
            "2063316488862721_2","2063316489612289_2","2063316486075393_2",
            "2063316486712321_2","2063316493194241_1","2063316491957249_1",
            "2063316492041217_1","2063316492125185_1","2063316491998209_1",
            "2063316492084225_1","2063316492168193_1","2063316492788737_1",
            "2063316492835841_1","2063316492878849_1","2063316492923905_1",
            "2063316492964865_1","2063316493007873_1","2063316492209153_1",
            "2063316493054977_1","2063316493136897_1","2063316493097985_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>  $baseData['2063316486075393_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2063316493194241_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电压',
                        "unit"=>"V",
                        "num"=> $baseData['2063316493136897_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=> $baseData['2063316486075393_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=> $baseData['2063316486712321_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2063316488862721_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2063316493194241_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电量',
                        "unit"=>"%",
                        "num"=> $baseData['2063316493097985_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2063316488862721_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2063316489612289_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    'label'=>'电压（V）',
                    'value_1'=>$baseData['2063316492209153_1'] ?? 0,
                    'value_2'=>$baseData['2063316493054977_1'] ?? 0,
                ],
                [
                    "label"=>"Ia1电流（A）",
                    'value_1'=>$baseData['2063316491957249_1'] ?? 0,
                    'value_2'=>$baseData['2063316492788737_1'] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    'value_1'=>$baseData['2063316492041217_1'] ?? 0,
                    'value_2'=>$baseData['2063316492878849_1'] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    'value_1'=>$baseData['2063316492125185_1'] ?? 0,
                    'value_2'=>$baseData['2063316492964865_1'] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    'value_1'=>$baseData['2063316491998209_1'] ?? 0,
                    'value_2'=>$baseData['2063316492835841_1'] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    'value_1'=>$baseData['2063316492084225_1'] ?? 0,
                    'value_2'=>$baseData['2063316492923905_1'] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    'value_1'=>$baseData['2063316492168193_1'] ?? 0,
                    'value_2'=>$baseData['2063316493007873_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 110207机巷
     */
    public function get110207jxList() {

        $keys=[
            "2059629797024769_1","2059629797067777_1","2059629797108737_1","2059629797192705_1",
            "2059629797233665_1","2059629797274625_1","2059629795988481_1","2059629796031489_1",
            "2059629796072449_1","2059629796158465_1","2059629796199425_1","2059629796238337_1",
            "2059629794612225_2","2059629795228673_2","2059629794855937_2","2059629795525633_2",
            "2059629798036481_1","2059629796819969_1","2059629796609025_1","2059629797950465_1",
            "2059629797708801_1","2060356330568705_1","2060356330460161_1","2059629796858881_1",
            "2059629797995521_1",
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>  $baseData['2059629794612225_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2059629798036481_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电压',
                        "unit"=>"V",
                        "num"=> $baseData['2060356330568705_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=> $baseData['2059629794612225_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=> $baseData['2059629794855937_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2059629795228673_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2059629798036481_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电量',
                        "unit"=>"%",
                        "num"=> $baseData['2060356330460161_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2059629795228673_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2059629795525633_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    'label'=>'电压（V）',
                    'value_1'=>$baseData['2059629796609025_1'] ?? 0,
                    'value_2'=>$baseData['2059629797708801_1'] ?? 0,
                ],
                [
                    "label"=>"前级A相电流（A）",
                    'value_1'=>$baseData['2059629795988481_1'] ?? 0,
                    'value_2'=>$baseData['2059629797024769_1'] ?? 0,
                ],
                [
                    "label"=>"前级B相电流（A）",
                    'value_1'=>$baseData['2059629796031489_1'] ?? 0,
                    'value_2'=>$baseData['2059629797067777_1'] ?? 0,
                ],
                [
                    "label"=>"前级C相电流（A）",
                    'value_1'=>$baseData['2059629796072449_1'] ?? 0,
                    'value_2'=>$baseData['2059629797108737_1'] ?? 0,
                ],
                [
                    "label"=>"后级A相电流（A）",
                    'value_1'=>$baseData['2059629796158465_1'] ?? 0,
                    'value_2'=>$baseData['2059629797192705_1'] ?? 0,
                ],
                [
                    "label"=>"后级B相电流（A）",
                    'value_1'=>$baseData['2059629796199425_1'] ?? 0,
                    'value_2'=>$baseData['2059629797233665_1'] ?? 0,
                ],
                [
                    "label"=>"后级C相电流（A）",
                    'value_1'=>$baseData['2059629796238337_1'] ?? 0,
                    'value_2'=>$baseData['2059629797274625_1'] ?? 0,
                ],
                [
                    "label"=>"额定电流（A）",
                    'value_1'=>$baseData['2059629796858881_1'] ?? 0,
                    'value_2'=>$baseData['2059629797995521_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 110207回风巷
     */
    public function get110207hfxList() {

        $keys=[
            "2059629797024769_1","2059629797067777_1","2059629797108737_1","2059629797192705_1",
            "2059629797233665_1","2059629797274625_1","2059629795988481_1","2059629796031489_1",
            "2059629796072449_1","2059629796158465_1","2059629796199425_1","2059629796238337_1",
            "2059629794612225_2","2059629795228673_2","2059629794855937_2","2059629795525633_2",
            "2059629798036481_1","2059629796819969_1","2059629796609025_1","2059629797950465_1",
            "2059629797708801_1","2060356330568705_1","2060356330460161_1","2059629796858881_1",
            "2059629797995521_1",
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>  $baseData['2059629794612225_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2059629798036481_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电压',
                        "unit"=>"V",
                        "num"=> $baseData['2060356330568705_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=> $baseData['2059629794612225_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=> $baseData['2059629794855937_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2059629795228673_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2059629798036481_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电量',
                        "unit"=>"%",
                        "num"=> $baseData['2060356330460161_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2059629795228673_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2059629795525633_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    'label'=>'电压（V）',
                    'value_1'=>$baseData['2059629796609025_1'] ?? 0,
                    'value_2'=>$baseData['2059629797708801_1'] ?? 0,
                ],
                [
                    "label"=>"前级A相电流（A）",
                    'value_1'=>$baseData['2059629795988481_1'] ?? 0,
                    'value_2'=>$baseData['2059629797024769_1'] ?? 0,
                ],
                [
                    "label"=>"前级B相电流（A）",
                    'value_1'=>$baseData['2059629796031489_1'] ?? 0,
                    'value_2'=>$baseData['2059629797067777_1'] ?? 0,
                ],
                [
                    "label"=>"前级C相电流（A）",
                    'value_1'=>$baseData['2059629796072449_1'] ?? 0,
                    'value_2'=>$baseData['2059629797108737_1'] ?? 0,
                ],
                [
                    "label"=>"后级A相电流（A）",
                    'value_1'=>$baseData['2059629796158465_1'] ?? 0,
                    'value_2'=>$baseData['2059629797192705_1'] ?? 0,
                ],
                [
                    "label"=>"后级B相电流（A）",
                    'value_1'=>$baseData['2059629796199425_1'] ?? 0,
                    'value_2'=>$baseData['2059629797233665_1'] ?? 0,
                ],
                [
                    "label"=>"后级C相电流（A）",
                    'value_1'=>$baseData['2059629796238337_1'] ?? 0,
                    'value_2'=>$baseData['2059629797274625_1'] ?? 0,
                ],
                [
                    "label"=>"额定电流（A）",
                    'value_1'=>$baseData['2059629796858881_1'] ?? 0,
                    'value_2'=>$baseData['2059629797995521_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五六分区220708回风巷
     */
    public function get220708hfxList() {

        $keys=[
            "2074999790310401_2","2074999791086593_2","2074999786576897_2","2074999787508737_2",
            "2074999793785857_1","2074999793845249_1","2074999793900545_1","2074999793945601_1",
            "2074999793992705_1","2074999794043905_1","2046522726851585_1","2046522726888449_1",
            "2046522726927361_1","2046522726962177_1","2046522726999041_1","2046522727037953_1",
            "2046522726392833_1","2074999794095105_1","2046522727113729_1","2074999795319809_1",
            "2074999794353153_1","2074999794545665_1","2074999793308673_1","2074999793490945_1",
            "2074999795504129_1","2074999795454977_1","2074999795393537_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>  $baseData['2074999786576897_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2074999795504129_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电压',
                        "unit"=>"V",
                        "num"=> $baseData['2074999795454977_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=> $baseData['2074999786576897_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=> $baseData['2074999787508737_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2074999790310401_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2074999795504129_1'] ?? 0,
                    ],
                    [
                        'label'=>'电池电量',
                        "unit"=>"%",
                        "num"=> $baseData['2074999795393537_1'] ?? 0,
                    ],
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2074999790310401_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2074999791086593_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    'label'=>'电压1（V）',
                    'value_1'=>$baseData['2046522726392833_1'] ?? 0,
                    'value_2'=>$baseData['2046522727113729_1'] ?? 0,
                ],
                [
                    'label'=>'电压2（V）',
                    'value_1'=>$baseData['2074999794095105_1'] ?? 0,
                    'value_2'=>$baseData['2074999795319809_1'] ?? 0,
                ],
                [
                    "label"=>"Ia1电流（A）",
                    'value_1'=>$baseData['2074999793785857_1'] ?? 0,
                    'value_2'=>$baseData['2046522726851585_1'] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    'value_1'=>$baseData['2046522726927361_1'] ?? 0,
                    'value_2'=>$baseData['2046522726888449_1'] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    'value_1'=>$baseData['2046522726999041_1'] ?? 0,
                    'value_2'=>$baseData['2046522726888449_1'] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    'value_1'=>$baseData['2074999793845249_1'] ?? 0,
                    'value_2'=>$baseData['2046522726962177_1'] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    'value_1'=>$baseData['2074999793945601_1'] ?? 0,
                    'value_2'=>$baseData['2046522726962177_1'] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    'value_1'=>$baseData['2074999794043905_1'] ?? 0,
                    'value_2'=>$baseData['2046522727037953_1'] ?? 0,
                ],
                [
                    "label"=>"1号断定值（倍）",
                    'value_1'=>$baseData['2074999793308673_1'] ?? 0,
                    'value_2'=>$baseData['2074999794353153_1'] ?? 0,
                ],
                [
                    "label"=>"2号断定值（倍）",
                    'value_1'=>$baseData['2074999793490945_1'] ?? 0,
                    'value_2'=>$baseData['2074999794545665_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五六分区220708胶带巷
     */
    public function get220708jdxList() {

        $keys=[
            "2046522721719297_2","2046522722276353_2","2046522723800065_2",
            "2046522724375553_2","2046522726140929_1","2046522726851585_1",
            "2046522726222849_1","2046522726927361_1","2046522726312961_1",
            "2046522726999041_1","2046522726181889_1","2046522726888449_1",
            "2046522726267905_1","2046522726962177_1","2046522726351873_1",
            "2046522727037953_1","2046522726392833_1","2046522727113729_1",
            "2046522725757953_1","2046522726511617_1","2046522725884929_1",
            "2046522726624257_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>  $baseData['2046522721719297_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=> $baseData['2046522721719297_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=> $baseData['2046522722276353_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2046522723800065_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2046522723800065_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2046522724375553_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    'value_1'=>$baseData['2046522726140929_1'] ?? 0,
                    'value_2'=>$baseData['2046522726851585_1'] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    'value_1'=>$baseData['2046522726222849_1'] ?? 0,
                    'value_2'=>$baseData['2046522726927361_1'] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    'value_1'=>$baseData['2046522726312961_1'] ?? 0,
                    'value_2'=>$baseData['2046522726999041_1'] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    'value_1'=>$baseData['2046522726181889_1'] ?? 0,
                    'value_2'=>$baseData['2046522726888449_1'] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    'value_1'=>$baseData['2046522726267905_1'] ?? 0,
                    'value_2'=>$baseData['2046522726962177_1'] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    'value_1'=>$baseData['2046522726351873_1'] ?? 0,
                    'value_2'=>$baseData['2046522727037953_1'] ?? 0,
                ],
                [
                    "label"=>"风机电压（V）",
                    'value_1'=>$baseData['2046522726392833_1'] ?? 0,
                    'value_2'=>$baseData['2046522727113729_1'] ?? 0,
                ],
                [
                    "label"=>"1号断定值（倍）",
                    'value_1'=>$baseData['2046522725757953_1'] ?? 0,
                    'value_2'=>$baseData['2046522726511617_1'] ?? 0,
                ],
                [
                    "label"=>"2号断定值（倍）",
                    'value_1'=>$baseData['2046522725884929_1'] ?? 0,
                    'value_2'=>$baseData['2046522726624257_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }
    /*
     * 五六分区220708辅助巷
     */
    public function get220708fzxList() {

        $keys=[
            "2046535459097601_2", "2046535459722241_2", "2046535461340161_2",
            "2046535461911553_2", "2046535463324673_1", "2046535463621633_1",
            "2046535463404545_1", "2046535463697409_1", "2046535463496705_1",
            "2046535463771137_1", "2046535463363585_1", "2046535463658497_1",
            "2046535463457793_1", "2046535463732225_1", "2046535463541761_1",
            "2046535463814145_1", "2046535463582721_1", "2046535463857153_1",
            "2046535463977985_1", "2046535464420353_1", "2046535464096769_1",
            "2046535464545281_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>$baseData['2046535459097601_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2046535459097601_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2046535459722241_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2046535461340161_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'1号电机',
                        "unit"=>"",
                        "num"=>$baseData['2046535461340161_2'] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData['2046535461911553_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    'value_1'=>$baseData['2046535463324673_1'] ?? 0,
                    'value_2'=>$baseData['2046535463621633_1'] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    'value_1'=>$baseData['2046535463404545_1'] ?? 0,
                    'value_2'=>$baseData['2046535463697409_1'] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    'value_1'=>$baseData['2046535463496705_1'] ?? 0,
                    'value_2'=>$baseData['2046535463771137_1'] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    'value_1'=>$baseData['2046535463363585_1'] ?? 0,
                    'value_2'=>$baseData['2046535463658497_1'] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    'value_1'=>$baseData['2046535463457793_1'] ?? 0,
                    'value_2'=>$baseData['2046535463732225_1'] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    'value_1'=>$baseData['2046535463541761_1'] ?? 0,
                    'value_2'=>$baseData['2046535463814145_1'] ?? 0,
                ],
                [
                    "label"=>"风机电压（V）",
                    'value_1'=>$baseData['2046535463582721_1'] ?? 0,
                    'value_2'=>$baseData['2046535463857153_1'] ?? 0,
                ],
                [
                    "label"=>"1号断定值（倍）",
                    'value_1'=>$baseData['2046535463977985_1'] ?? 0,
                    'value_2'=>$baseData['2046535464420353_1'] ?? 0,
                ],
                [
                    "label"=>"2号断定值（倍）",
                    'value_1'=>$baseData['2046535464096769_1'] ?? 0,
                    'value_2'=>$baseData['2046535464545281_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五六分区1200石门
     * 150201回风巷通风机
     */
    public function get1200smList() {

        $keys=[
            "2046522721719297_2", "2046522722276353_2", "2046522723800065_2",
            "2046522724375553_2", "2049479119457281_1", "2049479120241665_1",
            "2049479119539201_1", "2049479120333825_1", "2049479119623169_1",
            "2049479120442369_1", "2049479119500289_1", "2049479120284673_1",
            "2049479119582209_1", "2049479120399361_1", "2049479119660033_1",
            "2049479120485377_1", "2049479119709185_1", "2049479120528385_1",
            "2049479119100929_1", "2049479119832065_1", "2049479119215617_1",
            "2049479119997953_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=>$baseData['2046522721719297_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'巷道风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2061938360599553_1'] ?? 0,
                    ],
                    [
                        'label'=>'前级运行',
                        "unit"=>"",
                        "num"=>$baseData['2046522721719297_2'] ?? 0,
                    ],
                    [
                        "label"=>"后级运行",
                        "unit"=>"",
                        "num"=>$baseData['2046522722276353_2'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"副风机",
                'state'=>$baseData['2046522723800065_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'巷道风速',
                        "unit"=>"m/s",
                        "num"=> $baseData['2061938360599553_1'] ?? 0,
                    ],
                    [
                        'label'=>'前级运行',
                        "unit"=>"",
                        "num"=>$baseData['2046522723800065_2'] ?? 0,
                    ],
                    [
                        "label"=>"后级运行",
                        "unit"=>"",
                        "num"=>$baseData['2046522724375553_2'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    'value_1'=>$baseData['2049479119457281_1'] ?? 0,
                    'value_2'=>$baseData['2049479120241665_1'] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    'value_1'=>$baseData['2049479119539201_1'] ?? 0,
                    'value_2'=>$baseData['2049479120333825_1'] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    'value_1'=>$baseData['2049479119623169_1'] ?? 0,
                    'value_2'=>$baseData['2049479120442369_1'] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    'value_1'=>$baseData['2049479119500289_1'] ?? 0,
                    'value_2'=>$baseData['2049479120284673_1'] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    'value_1'=>$baseData['2049479119582209_1'] ?? 0,
                    'value_2'=>$baseData['2049479120399361_1'] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    'value_1'=>$baseData['2049479119660033_1'] ?? 0,
                    'value_2'=>$baseData['2049479120485377_1'] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    'value_1'=>$baseData['2049479119709185_1'] ?? 0,
                    'value_2'=>$baseData['2049479120528385_1'] ?? 0,
                ],
                [
                    "label"=>"1号断定值（倍）",
                    'value_1'=>$baseData['2049479119100929_1'] ?? 0,
                    'value_2'=>$baseData['2049479119832065_1'] ?? 0,
                ],
                [
                    "label"=>"2号断定值（倍）",
                    'value_1'=>$baseData['2049479119215617_1'] ?? 0,
                    'value_2'=>$baseData['2049479119997953_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五六分区1200车场
     * 150201机巷通风机
     */
    public function get1200CarFanList() {

        $keys=[
            "2049479008105473_2", "2049479008132097_2", "2049479011619841_1",
            "2049479011355649_1", "2049479011662849_1", "2049479011396609_1",
            "2049479009928193_1", "2049479011456001_1", "2049479010350081_1",
            "2049479011499009_1", "2049479010540545_1", "2049479011537921_1",
            "2049479010722817_1", "2049479011576833_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"主风机",
                'state'=> $baseData['2049479008105473_2'] ?? 0,
                'list'=>[
                ]
            ],
            [
                'title'=>"副风机",
                'state'=> $baseData['2049479008132097_2'] ?? 0,
                'list'=>[
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    'value_1'=> $baseData['2049479011619841_1'] ?? 0,
                    'value_2'=> $baseData['2049479011355649_1'] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    'value_1'=>$baseData['2049479011662849_1'] ?? 0,
                    'value_2'=>$baseData['2049479011396609_1'] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    'value_1'=>$baseData['2049479009928193_1'] ?? 0,
                    'value_2'=>$baseData['2049479011456001_1'] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    'value_1'=>$baseData['2049479010350081_1'] ?? 0,
                    'value_2'=>$baseData['2049479011499009_1'] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    'value_1'=>$baseData['2049479010540545_1'] ?? 0,
                    'value_2'=>$baseData['2049479011537921_1'] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    'value_1'=>$baseData['2049479010722817_1'] ?? 0,
                    'value_2'=>$baseData['2049479011576833_1'] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五分区通风系统
     */
    public function get5fqList() {

        $keys=[
            "2008681965886465_1","2008681965968385_1","2008682658571265_1","2008682658477057_1",
            "2008681965952001_1","2008682658585601_1","2008681965235201_1","2008682657807361_1",
            "2008682657917953_1","2008681965351937_1","2008681965386753_1","2008682657948673_1",
            "2008681965368321_1","2008682657932289_1","2008682657967105_1","2008681965407233_1",
            "2008681965919233_1","2008682658540545_1","2008682658558977_1","2008681965933569_1",
            "2008681965898753_1","2008682658497537_1","2008682658520065_1","2008681965908993_1",
            "2008681964536833_2","2008681964751873_2","2008682657094657_2","2008682657350657_2",
            "2008681964434433_2","2008681964655617_2","2008682656979969_2","2008682657248257_2",
            "2008681964383233_2","2008681964594177_2","2008682656934913_2","2008682657172481_2",
            "2008681964790785_2","2008681964805121_2","2008682657383425_2","2008682657395713_2",
            "2008681964422145_2","2008681964819457_2","2008681964643329_2","2008681964833793_2",
            "2008682656965633_2","2008682657405953_2","2008682657235969_2","2008682657416193_2",
            "2008681964463105_2","2008681964682241_2","2008682657008641_2","2008682657278977_2",
            "2008681964491777_2","2008681964704769_2","2008682657035265_2","2008682657303553_2",
            "2008682657338369_2","2008681964207105_2","2008681964219393_2","2008682656777217_2",
            "2008682656793601_2","2008682657074177_2","2008681964526593_2","2008681964741633_2",
            "2008681965315073_1","2008681965425665_1","2008681965462529_1","2008681965478913_1",
            "2008681965495297_1","2008681965333505_1","2008681965444097_1","2008681965509633_1",
            "2008681965523969_1","2008681965542401_1","2008682657885185_1","2008682657983489_1",
            "2008682658026497_1","2008682658044929_1","2008682658065409_1","2008682657901569_1",
            "2008682658003969_1","2008682658083841_1","2008682658100225_1","2008682658118657_1",
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        $data['tab']=[
            [
                'title'=>"1#风机",
                'state'=>$baseData['2008681964219393_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'全压',
                        "unit"=>"KPa",
                        "num"=>$baseData['2008681965886465_1'] ?? 0,
                    ],
                    [
                        'label'=>'负压',
                        "unit"=>"KPa",
                        "num"=>$baseData['2008681965952001_1'] ?? 0,
                    ],
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=>$baseData['2008681965968385_1'] ?? 0,
                    ],
                    [
                        'label'=>'风量',
                        "unit"=>"m³/min",
                        "num"=>$baseData['2008681965235201_1'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"2#风机",
                'state'=>$baseData['2008682656793601_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'全压',
                        "unit"=>"KPa",
                        "num"=>$baseData['2008682658477057_1'] ?? 0,
                    ],
                    [
                        'label'=>'负压',
                        "unit"=>"KPa",
                        "num"=>$baseData['2008682658571265_1'] ?? 0,
                    ],
                    [
                        'label'=>'风速',
                        "unit"=>"m/s",
                        "num"=>$baseData['2008682658585601_1'] ?? 0,
                    ],
                    [
                        'label'=>'风量',
                        "unit"=>"m³/min",
                        "num"=>$baseData['2008682657807361_1'] ?? 0,
                    ],
                ]
            ]
        ];

        $data['table_1']=[
            "thead"=>[
                "参数名称", "1-1", "1-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电流反馈（A）",
                    'value_1'=>$baseData['2008681965351937_1'] ?? 0,
                    'value_2'=>$baseData['2008681965386753_1'] ?? 0,
                ],
                [
                    "label"=>"频率反馈（Hz）",
                    'value_1'=>$baseData['2008681965368321_1'] ?? 0,
                    'value_2'=>$baseData['2008681965407233_1'] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    'value_1'=>$baseData['2008681965919233_1'] ?? 0,
                    'value_2'=>$baseData['2008681965933569_1'] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    'value_1'=>$baseData['2008681965898753_1'] ?? 0,
                    'value_2'=>$baseData['2008681965908993_1'] ?? 0,
                ],
                [
                    "label"=>"报警",
                    'value_1'=>$baseData['2008681964536833_2']==1 ? '正常':'报警',
                    'value_2'=>$baseData['2008681964751873_2']==1 ? '正常':'报警',
                ],
                [
                    "label"=>"变频器故障",
                    'value_1'=>$baseData['2008681964434433_2']==1 ? '故障':'无故障',
                    'value_2'=>$baseData['2008681964655617_2']==1 ? '故障':'无故障',
                ],
                [
                    "label"=>"变频器就绪",
                    'value_1'=>$baseData['2008681964383233_2']==1 ? '就绪':'未就绪',
                    'value_2'=>$baseData['2008681964594177_2']==1 ? '就绪':'未就绪',
                ],
                [
                    "label"=>"集控/就地",
                    'value_1'=>$baseData['2008681964790785_2']==1 ? '集控':'就地',
                    'value_2'=>$baseData['2008681964805121_2']==1 ? '集控':'就地',
                ],
                [
                    "label"=>"工/变频",
                    'value_1'=>$baseData['2008681964422145_2']==1 ? '变频':'工频',
                    'value_2'=>$baseData['2008681964643329_2']==1 ? '变频':'工频',
                ],
                [
                    "label"=>"正/反转",
                    'value_1'=>$baseData['2008681964463105_2']==1 ? '正转':'反转',
                    'value_2'=>$baseData['2008681964682241_2']==1 ? '正转':'反转',
                ],
                [
                    "label"=>"允许开机",
                    'value_1'=>$baseData['2008681964491777_2']==0 ? '允许':'禁止',
                    'value_2'=>$baseData['2008681964704769_2']==0 ? '允许':'禁止',
                ],
            ]
        ];
        $data['table_2']=[
            "thead"=>[
                "参数名称", "2-1", "2-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电流反馈（A）",
                    'value_1'=>$baseData['2008682657917953_1'] ?? 0,
                    'value_2'=>$baseData['2008682657948673_1'] ?? 0,
                ],
                [
                    "label"=>"频率反馈（Hz）",
                    'value_1'=>$baseData['2008682657932289_1'] ?? 0,
                    'value_2'=>$baseData['2008682657967105_1'] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    'value_1'=>$baseData['2008682658540545_1'] ?? 0,
                    'value_2'=>$baseData['2008682658558977_1'] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    'value_1'=>$baseData['2008682658497537_1'] ?? 0,
                    'value_2'=>$baseData['2008682658520065_1'] ?? 0,
                ],
                [
                    "label"=>"报警",
                    'value_1'=>$baseData['2008682657094657_2']==1 ? '正常':'报警',
                    'value_2'=>$baseData['2008682657350657_2']==1 ? '正常':'报警',
                ],
                [
                    "label"=>"变频器故障",
                    'value_1'=>$baseData['2008682656979969_2']==1 ? '故障':'无故障',
                    'value_2'=>$baseData['2008682657248257_2']==1 ? '故障':'无故障',
                ],
                [
                    "label"=>"变频器就绪",
                    'value_1'=>$baseData['2008682656934913_2']==1 ? '就绪':'未就绪',
                    'value_2'=>$baseData['2008682657172481_2']==1 ? '就绪':'未就绪',
                ],
                [
                    "label"=>"集控/就地",
                    'value_1'=>$baseData['2008682657383425_2']==1 ? '集控':'就地',
                    'value_2'=>$baseData['2008682657395713_2']==1 ? '集控':'就地',
                ],
                [
                    "label"=>"工/变频",
                    'value_1'=>$baseData['2008682656965633_2']==1 ? '变频':'工频',
                    'value_2'=>$baseData['2008682657235969_2']==1 ? '变频':'工频',
                ],
                [
                    "label"=>"正/反转",
                    'value_1'=>$baseData['2008682657008641_2']==1 ? '正传':'反转',
                    'value_2'=>$baseData['2008682657278977_2']==1 ? '正传':'反转',
                ],
                [
                    "label"=>"允许开机",
                    'value_1'=>$baseData['2008682657035265_2']==0 ? '允许':'禁止',
                    'value_2'=>$baseData['2008682657303553_2']==0 ? '允许':'禁止',
                ],
            ]
        ];
        $data['chartData_1']=[
            'categories'=>["1-1#电机", "1-2#电机"],
            'series'=>[
                [
                    "name"=>'前轴温度',
                    "data"=>[
                        $baseData['2008681965315073_1'] ?? 0,
                        $baseData['2008681965333505_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'后轴温度',
                    "data"=>[
                        $baseData['2008681965425665_1'] ?? 0,
                        $baseData['2008681965444097_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'定子A温度',
                    "data"=>[
                        $baseData['2008681965462529_1'] ?? 0,
                        $baseData['2008681965509633_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'定子B温度',
                    "data"=>[
                        $baseData['2008681965478913_1'] ?? 0,
                        $baseData['2008681965523969_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'定子C温度',
                    "data"=>[
                        $baseData['2008681965542401_1'] ?? 0,
                        $baseData['2008681965495297_1'] ?? 0,
                    ],
                ],
            ]
        ];
        $data['chartData_2']=[
            'categories'=>["2-1#电机", "2-2#电机"],
            'series'=>[
                [
                    "name"=>'前轴温度',
                    "data"=>[
                        $baseData['2008682657885185_1'] ?? 0,
                        $baseData['2008682657901569_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'后轴温度',
                    "data"=>[
                        $baseData['2008682657983489_1'] ?? 0,
                        $baseData['2008682658003969_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度u',
                    "data"=>[
                        $baseData['2008682658026497_1'] ?? 0,
                        $baseData['2008682658083841_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度v',
                    "data"=>[
                        $baseData['2008682658044929_1'] ?? 0,
                        $baseData['2008682658100225_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度w',
                    "data"=>[
                        $baseData['2008682658065409_1'] ?? 0,
                        $baseData['2008682658118657_1'] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }
    /*
     * 1314通风
     */
    public function get1314List() {

        $keys=[
            "2009721038035969_1","2009721038019585_1","2009721038052353_1",
            "2009721038083073_1","2009721038113793_1","2009721049226241_1",
            "2009721049205761_1","2009721049244673_1","2009721049283585_1",
            "2009721049318401_1","2009721047624705_2","2009721036276737_2",
            "2009721035631617_2","2009721047067649_2","2009721035617281_2",
            "2009721047053313_2","2009735057300481_1","2009735057363969_1",
            "2009735057392641_1","2009735057468417_1","2009735057378305_1",
            "2009735057484801_1","2009735057349633_1","2009735057449985_1",
            "2009735057103873_1","2009735057161217_1","2009735057193985_1",
            "2009735057263617_1","2009721037777921_1","2009735057282049_1",
            "2009735057146881_1","2009735057247233_1","2009735057501185_1",
            "2009735057515521_1","2009735057529857_1","2009735057546241_1",
            "2009721037796353_1","2009721048970241_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];
        // 电流、功率、振动、负压取的西井通风的点
        $data['tab']=[
            [
                'title'=>"1#风机",
                'state'=>$baseData['2009721035631617_2'] ?? 0,
                'list'=>[
                ]
            ],
            [
                'title'=>"2#风机",
                'state'=>$baseData['2009721047067649_2'] ?? 0,
                'list'=>[
                ]
            ]
        ];
        $data['table_1']=[
            "thead"=>[
                "参数名称", "前级", "后级"
            ],
            "tbody"=>[
                [
                    "label"=>"运行频率（Hz）",
                    'value_1'=>$baseData['2009721037796353_1'] ?? 0,
                    'value_2'=>$baseData['2009721037796353_1'] ?? 0,
                ],
                [
                    "label"=>"运行电流（A）",
                    'value_1'=>$baseData['2009735057300481_1'] ?? 0,
                    'value_2'=>$baseData['2009735057392641_1'] ?? 0,
                ],
                [
                    "label"=>"运行功率（kw)",
                    'value_1'=>$baseData['2009735057363969_1'] ?? 0,
                    'value_2'=>$baseData['2009735057468417_1'] ?? 0,
                ],
                [
                    "label"=>"X振动（mm/s)",
                    'value_1'=>$baseData['2009735057378305_1'] ?? 0,
                    'value_2'=>$baseData['2009735057484801_1'] ?? 0,
                ],
                [
                    "label"=>"Y振动（mm/s)",
                    'value_1'=>$baseData['2009735057349633_1'] ?? 0,
                    'value_2'=>$baseData['2009735057449985_1'] ?? 0,
                ],
                [
                    "label"=>"负压（pa)",
                    'value_1'=>$baseData['2009735057529857_1'] ?? 0,
                    'value_2'=>$baseData['2009735057546241_1'] ?? 0,
                ],
            ]
        ];
        $data['table_2']=[
            "thead"=>[
                "参数名称", "前级", "后级"
            ],
            "tbody"=>[
                [
                    "label"=>"运行频率（Hz）",
                    'value_1'=>$baseData['2009721048970241_1'] ?? 0,
                    'value_2'=>$baseData['2009721048970241_1'] ?? 0,
                ],
                [
                    "label"=>"运行电流（A）",
                    'value_1'=>$baseData['2009735057103873_1'] ?? 0,
                    'value_2'=>$baseData['2009735057193985_1'] ?? 0,
                ],
                [
                    "label"=>"运行功率（kw)",
                    'value_1'=>$baseData['2009735057161217_1'] ?? 0,
                    'value_2'=>$baseData['2009735057263617_1'] ?? 0,
                ],
                [
                    "label"=>"X振动（mm/s)",
                    'value_1'=>$baseData['2009721037777921_1'] ?? 0,
                    'value_2'=>$baseData['2009735057282049_1'] ?? 0,
                ],
                [
                    "label"=>"Y振动（mm/s)",
                    'value_1'=>$baseData['2009735057146881_1'] ?? 0,
                    'value_2'=>$baseData['2009735057247233_1'] ?? 0,
                ],
                [
                    "label"=>"负压（pa)",
                    'value_1'=>$baseData['2009735057501185_1'] ?? 0,
                    'value_2'=>$baseData['2009735057515521_1'] ?? 0,
                ],
            ]
        ];
        $data['chartData_1']=[
            'categories'=>["1-1#电机", "1-2#电机"],
            'series'=>[
                [
                    "name"=>'前轴温度',
                    "data"=>[
                        $baseData['2009721038035969_1'] ?? 0,
                        $baseData['2009721038035969_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'后轴温度',
                    "data"=>[
                        $baseData['2009721038019585_1'] ?? 0,
                        $baseData['2009721038019585_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度u',
                    "data"=>[
                        $baseData['2009721038052353_1'] ?? 0,
                        $baseData['2009721038052353_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度v',
                    "data"=>[
                        $baseData['2009721038083073_1'] ?? 0,
                        $baseData['2009721038083073_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度w',
                    "data"=>[
                        $baseData['2009721038113793_1'] ?? 0,
                        $baseData['2009721038113793_1'] ?? 0,
                    ],
                ],
            ]
        ];
        $data['chartData_2']=[
            'categories'=>["2-1#电机", "2-2#电机"],
            'series'=>[
                [
                    "name"=>'前轴温度',
                    "data"=>[
                        $baseData['2009721049226241_1'] ?? 0,
                        $baseData['2009721049226241_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'后轴温度',
                    "data"=>[
                        $baseData['2009721049205761_1'] ?? 0,
                        $baseData['2009721049205761_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度u',
                    "data"=>[
                        $baseData['2009721049244673_1'] ?? 0,
                        $baseData['2009721049244673_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度v',
                    "data"=>[
                        $baseData['2009721049283585_1'] ?? 0,
                        $baseData['2009721049283585_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度w',
                    "data"=>[
                        $baseData['2009721049318401_1'] ?? 0,
                        $baseData['2009721049318401_1'] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }

    /*
     * 西井通风
     */
    public function getWestList() {

        $keys=[
            "2008290869144577_1","2008290869222401_1","2008290869236737_1",
            "2008290869253121_1","2008290869267457_1","2008290869279745_1",
            "2008290869292033_1","2008290869308417_1","2008290869326849_1",
            "2008290869345281_1","2008290869365761_1","2008290869384193_1",
            "2008290869404673_1","2008290869421057_1","2008290869439489_1",
            "2008290869457921_1","2008290869474305_1","2008290869484545_1",
            "2008290869498881_1","2008290869519361_1","2009735056086017_2",
            "2009735056098305_2","2009735056108545_2","2009735056387073_2",
            "2009735056399361_2","2009735056409601_2","2009735056724993_2",
            "2009735056737281_2","2009735056749569_2","2009735056907265_2",
            "2009735056919553_2","2009735056929793_2","2009735057103873_1",
            "2009735057116161_1","2009735057146881_1","2009735057161217_1",
            "2009735057177601_1","2009735057193985_1","2009735057212417_1",
            "2009735057247233_1","2009735057263617_1","2009735057282049_1",
            "2009735057300481_1","2009735057314817_1","2009735057349633_1",
            "2009735057363969_1","2009735057378305_1","2009735057392641_1",
            "2009735057413121_1","2009735057449985_1","2009735057468417_1",
            "2009735057484801_1","2009735057501185_1","2009735057515521_1",
            "2009735057529857_1","2009735057546241_1"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        // 风速和电压是假数据，风门状态不确定

        $data['tab']=[
            [
                'title'=>"1#风机",
                'state'=>$baseData['2009735056108545_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'体积流量',
                        "unit"=>"Pa",
                        "num"=>rand(81000, 87000) / 10.0,
                    ],
                    [
                        "label"=>"出口风速",
                        "unit"=>"m/s",
                        "num"=>6.4,
                    ],
                ]
            ],
            [
                'title'=>"2#风机",
                'state'=>$baseData['2009735056749569_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'体积流量',
                        "unit"=>"Pa",
                        "num"=>0,
                    ],
                    [
                        "label"=>"出口风速",
                        "unit"=>"m/s",
                        "num"=>0.0,
                    ],
                ]
            ]
        ];
        $data['table_1']=[
            "thead"=>[
                "参数名称", "1-1", "1-2"
            ],
            "tbody"=>[
                [
                    "label"=>"负压（Pa)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057501185_1'] * 10 ?? 0,
                    'value_2'=>$baseData['2009735057515521_1'] * 10 ?? 0,
                ],
                [
                    "label"=>"运行频率（HZ)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057116161_1'] ?? 0,
                    'value_2'=>$baseData['2009735057212417_1'] ?? 0,
                ],
                [
                    "label"=>"运行电流（A)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057103873_1'] ?? 0,
                    'value_2'=>$baseData['2009735057193985_1'] ?? 0,
                ],
                [
                    "label"=>"运行电压（V)",
                    "type"=>"val",
                    "value_1"=>381,
                    "value_2"=>384,
                ],
                [
                    "label"=>"运行功率(kw)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057161217_1'] ?? 0,
                    'value_2'=>$baseData['2009735057263617_1'] ?? 0,
                ],
                [
                    "label"=>"水平振动(mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057177601_1'] ?? 0,
                    'value_2'=>$baseData['2009735057282049_1'] ?? 0,
                ],
                [
                    "label"=>"垂直振动(mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057146881_1'] ?? 0,
                    'value_2'=>$baseData['2009735057247233_1'] ?? 0,
                ],
                [
                    "label"=>"故障信息",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735056086017_2'] ?? 0,
                    'value_2'=>$baseData['2009735056387073_2'] ?? 0,
                ],
                [
                    "label"=>"运行状态",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735056108545_2'] ?? 0,
                    'value_2'=>$baseData['2009735056409601_2'] ?? 0,
                ],
                [
                    "label"=>"允许信号",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735056098305_2'] ?? 0,
                    'value_2'=>$baseData['2009735056399361_2'] ?? 0,
                ],
            ]
        ];
        $data['table_2']=[
            "thead"=>[
                "参数名称", "2-1", "2-2"
            ],
            "tbody"=>[
                [
                    "label"=>"负压（Pa)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057529857_1'] ?? 0,
                    'value_2'=>$baseData['2009735057546241_1'] ?? 0,
                ],
                [
                    "label"=>"运行频率（HZ)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057314817_1'] ?? 0,
                    'value_2'=>$baseData['2009735057413121_1'] ?? 0,
                ],
                [
                    "label"=>"运行电流（A)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057300481_1'] ?? 0,
                    'value_2'=>$baseData['2009735057392641_1'] ?? 0,
                ],
                [
                    "label"=>"运行电压（V)",
                    "type"=>"val",
                    "value_1"=>383,
                    "value_2"=>380,
                ],
                [
                    "label"=>"运行功率(kw)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057363969_1'] ?? 0,
                    'value_2'=>$baseData['2009735057468417_1'] ?? 0,
                ],
                [
                    "label"=>"水平振动(mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057378305_1'] ?? 0,
                    'value_2'=>$baseData['2009735057484801_1'] ?? 0,
                ],
                [
                    "label"=>"垂直振动(mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735057349633_1'] ?? 0,
                    'value_2'=>$baseData['2009735057449985_1'] ?? 0,
                ],
                [
                    "label"=>"故障信息",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735056724993_2'] ?? 0,
                    'value_2'=>$baseData['2009735056907265_2'] ?? 0,
                ],
                [
                    "label"=>"运行状态",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735056749569_2'] ?? 0,
                    'value_2'=>$baseData['2009735056929793_2'] ?? 0,
                ],
                [
                    "label"=>"允许信号",
                    "type"=>"val",
                    'value_1'=>$baseData['2009735056737281_2'] ?? 0,
                    'value_2'=>$baseData['2009735056919553_2'] ?? 0,
                ],
            ]
        ];
        $data['chartData_1']=[
            'categories'=>["1-1#电机", "1-2#电机"],
            'series'=>[
                [
                    "name"=>'前轴温度',
                    "data"=>[
                        $baseData['2008290869144577_1'] ?? 0,
                        $baseData['2008290869279745_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'后轴温度',
                    "data"=>[
                        $baseData['2008290869222401_1'] ?? 0,
                        $baseData['2008290869292033_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度1',
                    "data"=>[
                        $baseData['2008290869236737_1'] ?? 0,
                        $baseData['2008290869308417_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度2',
                    "data"=>[
                        $baseData['2008290869253121_1'] ?? 0,
                        $baseData['2008290869326849_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度3',
                    "data"=>[
                        $baseData['2008290869267457_1'] ?? 0,
                        $baseData['2008290869345281_1'] ?? 0,
                    ],
                ],
            ]
        ];
        $data['chartData_2']=[
            'categories'=>["2-1#电机", "2-2#电机"],
            'series'=>[
                [
                    "name"=>'前轴温度',
                    "data"=>[
                        $baseData['2008290869365761_1'] ?? 0,
                        $baseData['2008290869457921_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'后轴温度',
                    "data"=>[
                        $baseData['2008290869384193_1'] ?? 0,
                        $baseData['2008290869474305_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度1',
                    "data"=>[
                        $baseData['2008290869404673_1'] ?? 0,
                        $baseData['2008290869484545_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度2',
                    "data"=>[
                        $baseData['2008290869421057_1'] ?? 0,
                        $baseData['2008290869498881_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度3',
                    "data"=>[
                        $baseData['2008290869439489_1'] ?? 0,
                        $baseData['2008290869519361_1'] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }

    /*
     * 东井通风
     */
    public function getEastList() {

        $keys=[
            "2008298770912257_2","2008298770922497_2","2008298770955265_2",
            "2008298771235841_2","2008298771252225_2","2008298771299329_2",
            "2008298771575809_2","2008298771590145_2","2008298771627009_2",
            "2008298771760129_2","2008298771774465_2","2008298771809281_2",
            "2008298771971073_1","2008298771987457_1","2008298772003841_1",
            "2008298772069377_1","2008298772089857_1","2008298772098049_1",
            "2008298772108289_1","2008298772118529_1","2008298772132865_1",
            "2008298772149249_1","2008298772163585_1","2008298772208641_1",
            "2008298772225025_1","2008298772239361_1","2008298772255745_1",
            "2008298772274177_1","2008298772323329_1","2008298772339713_1",
            "2008298772354049_1","2008298772370433_1","2008298772388865_1",
            "2008298772425729_1","2008298772444161_1","2008298772464641_1",
            "2008298772485121_1","2008298772503553_1","2008298772524033_1",
            "2008298772542465_1","2008298772589569_1","2008298772605953_1",
            "2008298772624385_1","2008298772642817_1","2008298772657153_1",
            "2008298772677633_1","2008298772696065_1","2008298772714497_1",
            "2008298772730881_1","2008298772747265_1","2008298772763649_1",
            "2008298772780033_1","2008319841133569_2","2008319841389569_2"
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest['data'] == 0) {
            $msg = $dataFromGetRequest['Message'];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest['data'];

        // 风量从接口取的对不上数据
        $data['tab']=[
            [
                'title'=>"1#风机",
                "state"=>$baseData['2008319841133569_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'负压',
                        "unit"=>"Pa",
                        "num"=>$baseData['2008298772069377_1'] ?? 0,
                    ],
                    [
                        // 接口数据对不上
                        "label"=>"风量",
                        "unit"=>"m³/min",
                        "num"=>$baseData['2008298772323329_1'] ?? 0,
                    ],
                ]
            ],
            [
                'title'=>"2#风机",
                "state"=>$baseData['2008319841389569_2'] ?? 0,
                'list'=>[
                    [
                        'label'=>'负压',
                        "unit"=>"Pa",
                        "num"=>$baseData['2008298772388865_1'] ?? 0,
                    ],
                    [
                        // 接口没有
                        "label"=>"风量",
                        "unit"=>"m³/min",
                        "num"=>$baseData['2008298772677633_1'] ?? 0,
                    ],
                ]
            ]
        ];
        $data['table_1']=[
            "thead"=>[
                "参数名称", "1-1", "1-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电机电流（A)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298771987457_1'] ?? 0,
                    'value_2'=>$baseData['2008298772354049_1'] ?? 0,
                ],
                [
                    "label"=>"变频频率（HZ)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772003841_1'] ?? 0,
                    'value_2'=>$baseData['2008298772370433_1'] ?? 0,
                ],
                [
                    "label"=>"设定频率（HZ)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298771971073_1'] ?? 0,
                    'value_2'=>$baseData['2008298772339713_1'] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772149249_1'] ?? 0,
                    'value_2'=>$baseData['2008298772149249_1'] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772163585_1'] ?? 0,
                    'value_2'=>$baseData['2008298772163585_1'] ?? 0,
                ],
                [
                    "label"=>"变频器状态",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298770955265_2'] ?? 0,
                    'value_2'=>$baseData['2008298771299329_2'] ?? 0,
                ],
                [
                    "label"=>"变频器就绪",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298770912257_2'] ?? 0,
                    'value_2'=>$baseData['2008298771235841_2'] ?? 0,
                ],
                [
                    "label"=>"变频器故障",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298770922497_2'] ?? 0,
                    'value_2'=>$baseData['2008298771252225_2'] ?? 0,
                ],
            ]
        ];
        $data['table_2']=[
            "thead"=>[
                "参数名称", "2-1", "2-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电机电流（A)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772714497_1'] ?? 0,
                    'value_2'=>$baseData['2008298772763649_1'] ?? 0,
                ],
                [
                    "label"=>"变频频率（HZ)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772730881_1'] ?? 0,
                    'value_2'=>$baseData['2008298772780033_1'] ?? 0,
                ],
                [
                    "label"=>"设定频率（HZ)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772696065_1'] ?? 0,
                    'value_2'=>$baseData['2008298772747265_1'] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772524033_1'] ?? 0,
                    'value_2'=>$baseData['2008298772524033_1'] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298772542465_1'] ?? 0,
                    'value_2'=>$baseData['2008298772542465_1'] ?? 0,
                ],
                [
                    "label"=>"变频器状态",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298771627009_2'] ?? 0,
                    'value_2'=>$baseData['2008298771809281_2'] ?? 0,
                ],
                [
                    "label"=>"变频器就绪",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298771575809_2'] ?? 0,
                    'value_2'=>$baseData['2008298771760129_2'] ?? 0,
                ],
                [
                    "label"=>"变频器故障",
                    "type"=>"val",
                    'value_1'=>$baseData['2008298771590145_2'] ?? 0,
                    'value_2'=>$baseData['2008298771774465_2'] ?? 0,
                ],
            ]
        ];
        $data['chartData_1']=[
            'categories'=>["1-1#电机", "1-2#电机"],
            'series'=>[
                [
                    "name"=>'绕组温度1',
                    "data"=>[
                        $baseData['2008298772108289_1'] ?? 0,
                        $baseData['2008298772239361_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'绕组温度2',
                    "data"=>[
                        $baseData['2008298772118529_1'] ?? 0,
                        $baseData['2008298772255745_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度3',
                    "data"=>[
                        $baseData['2008298772132865_1'] ?? 0,
                        $baseData['2008298772274177_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'轴承温度1',
                    "data"=>[
                        $baseData['2008298772089857_1'] ?? 0,
                        $baseData['2008298772208641_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'轴承温度2',
                    "data"=>[
                        $baseData['2008298772098049_1'] ?? 0,
                        $baseData['2008298772225025_1'] ?? 0,
                    ],
                ],
            ]
        ];
        $data['chartData_2']=[
            'categories'=>["2-1#电机", "2-2#电机"],
            'series'=>[
                [
                    "name"=>'绕组温度1',
                    "data"=>[
                        $baseData['2008298772464641_1'] ?? 0,
                        $baseData['2008298772624385_1'] ?? 0,
                    ],
                ],
                [
                    "name"=>'绕组温度2',
                    "data"=>[
                        $baseData['2008298772485121_1'] ?? 0,
                        $baseData['2008298772642817_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'绕组温度3',
                    "data"=>[
                        $baseData['2008298772503553_1'] ?? 0,
                        $baseData['2008298772657153_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'轴承温度1',
                    "data"=>[
                        $baseData['2008298772425729_1'] ?? 0,
                        $baseData['2008298772589569_1'] ?? 0,

                    ],
                ],
                [
                    "name"=>'轴承温度2',
                    "data"=>[
                        $baseData['2008298772444161_1'] ?? 0,
                        $baseData['2008298772605953_1'] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }

    public function getKeysDataArr($type) {

        if (isset($type)) {

            $sqlStr = "select distinct `point_id`, `point_name` from `dcs_point_final_dic` where `sys_num` = $type";
            $res = $this->executeSql($sqlStr, $type);
            // return $res;
            $keys=[];
            $keys_dic=[];
            for ($i = 0; $i < count($res); $i++) {
                // $data=$res[$i];
                // return $data;
                $key=$res[$i]->point_id;
                $keyName=$res[$i]->point_name;
                $keys[]=$key;
                $keys_dic[$key]=$keyName;
            }

            $keyArr=[
                'keys'=>$keys,
                'keys_dic'=>$keys_dic
            ];

            return $keyArr;
        }

        return null;

    }

    public function getBaseDataArr($tb_name, $data_key) {

        $point_id = "'" . implode("','", $data_key) . "'";
        // 构建 SQL 查询
        $sqlStr = "select `point_id`, `value` from $tb_name where `point_id` in ($point_id)";

        $res = $this->executeSql($sqlStr, 1);
        $baseData=[];
        for ($i = 0; $i < count($res); $i++) {
            $key=$res[$i]->point_id;
            $val=$res[$i]->value;
            $baseData[$key]=$val;
        }
        return $baseData;
    }

    public function getDBDataFrom($tb_name, $where='') {
        // 构建 SQL 查询
        $sqlStr = "select * from {$tb_name} where ({$where})";
        $res = $this->executeSql($sqlStr, 3);
        return $res;
    }

    public function executeSql($sqlStr, $modelname = -1) {

        try{
            $opcDB =  DB::connection($this->db_name);
            $dbResult = $opcDB->select($sqlStr);
            return $dbResult;
        } catch (\Exception $e) {
            switch ($modelname) {
                case 1:
                    return $this->error(-1, '东井通风');
                case 2:
                    return $this->error(-1, '统计日超速出错！');
                case 4:
                    return $this->error(-1, '获取详细列表出错！');
                default:
                    return $this->error(-1, '数据库查询错误！');
            }

        }
    }

}
